# json-logger

## Description
* A simple logger that logs in a JSON format

#### Generated by CookieCutter
* Repository: [GitHub](https://github.com/btr1975/cookiecutter-python-library)
* Version: 1.0.3
